function [data, auxData, metaData, txtData, weights] = mydata_Ursus_maritimus

%% set metaData
metaData.phylum     = 'Chordata'; 
metaData.class      = 'Mammalia'; 
metaData.order      = 'Carnivora'; 
metaData.family     = 'Ursidae';
metaData.species    = 'Ursus_maritimus'; 
metaData.species_en = 'Polar bear'; 

metaData.ecoCode.climate = {'ME'};
metaData.ecoCode.ecozone = {'MN'};
metaData.ecoCode.habitat = {'0iMc'};
metaData.ecoCode.embryo  = {'Tv'};
metaData.ecoCode.migrate = {'Ms','TT'};
metaData.ecoCode.food    = {'bxM', 'xiCvm'};
metaData.ecoCode.gender  = {'Dg'};
metaData.ecoCode.reprod  = {'O'};

metaData.T_typical  = C2K(36.8); % K, body temp
metaData.data_0     = {'tg'; 'ax'; 'ap'; 'am'; 'Li'; 'Wwb'; 'Wwx'; 'Wwp';  'Wwi'; 'Ri'};  
metaData.data_1     = {'t-Ww'; 't-L'}; 

metaData.COMPLETE = 2.5; % using criteria of LikaKear2011

metaData.author   = {'Jean-Pierre Desforges'};    
metaData.date_subm = [2016 11 05];              
metaData.email    = {'jpd@bios.au.dk'};            
metaData.address  = {'Aarhus University'};   

metaData.author_mod_1   = {'Jean-Pierre Desforges'};    
metaData.date_mod_1 = [2017 05 30];              
metaData.email_mod_1    = {'jpd@bios.au.dk'};            
metaData.address_mod_1  = {'Aarhus University'};   

metaData.curator     = {'Starrlight Augustine'};
metaData.email_cur   = {'starrlight.augustine@akvaplan.niva.no'}; 
metaData.date_acc    = [2017 06 22];  

%% set data
% zero-variate data
data.tg = 230;    units.tg = 'd';    label.tg = 'gestation time';                bibkey.tg = 'AnAge';   
  temp.tg = C2K(36.8);  units.temp.tg = 'K'; label.temp.tg = 'temperature';
data.tx = 876;    units.tx = 'd';    label.tx = 'time since birth at weaning'; bibkey.tx = 'DeroWiig2002';    
  temp.tx = C2K(36.8);  units.temp.tx = 'K'; label.temp.tx = 'temperature';
data.tp = 4.4*365;   units.tp = 'd';    label.tp = 'time since birth at puberty for female'; bibkey.tp = 'DeroWiig2002';
  temp.tp = C2K(36.8);  units.temp.tp = 'K'; label.temp.tp = 'temperature'; 
data.tp_m = 6.2*365;   units.tp_m = 'd';    label.tp_m = 'time since birth at puberty for male'; bibkey.tp_m = 'DeroWiig2002';
  temp.tp_m = C2K(36.8);  units.temp.tp_m = 'K'; label.temp.tp_m = 'temperature'; 
data.am = 43*365; units.am = 'd';    label.am = 'life span';                   bibkey.am = 'AnAge';   
  temp.am = C2K(36.8);  units.temp.am = 'K'; label.temp.am = 'temperature'; 

data.Li  = 194;   units.Li  = 'cm';  label.Li  = 'ultimate head-body length for female';  bibkey.Li  = 'DeroWiig2002';
data.Li_m  = 225;  units.Li_m  = 'cm'; label.Li_m  = 'ultimate head-body length for male';   bibkey.Li_m  = 'DeroWiig2002';
 
data.Wwb = 665;   units.Wwb = 'g';   label.Wwb = 'wet weight at birth';        bibkey.Wwb = 'AnAge';
data.Wwx = 102000; units.Wwx = 'g';   label.Wwx = 'wet weight at weaning';      bibkey.Wwx = 'DeroWiig2002';
data.Wwp = 154000; units.Wwp = 'g';   label.Wwp = 'wet weight at puberty for females';      bibkey.Wwp = 'DeroWiig2002';
data.Wwp_m = 285000; units.Wwp_m = 'g';   label.Wwp_m = 'wet weight at puberty for males';      bibkey.Wwp_m = 'DeroWiig2002';
data.Wwi = 185000; units.Wwi = 'g';  label.Wwi = 'ultimate wet weight for female';        bibkey.Wwi = 'DeroWiig2002';
data.Wwi_m = 389000; units.Wwi_m = 'g';  label.Wwi_m = 'ultimate wet weight for male';        bibkey.Wwi_m = 'DeroWiig2002';
%data.Wwm = 280000; units.Wwm = 'g';  label.Wwm = 'maximum wet weight for females';        bibkey.Wwm = 'DeroWiig2002';
%data.Wwm_m = 525000; units.Wwm_m = 'g';  label.Wwm_m = 'maximum wet weight for males';        bibkey.Wwm_m = 'DeroWiig2002';

data.Ri  = 2/750;   units.Ri  = '#/d'; label.Ri  = 'maximum reprod rate';      bibkey.Ri  = 'AnAge';   
  temp.Ri = C2K(36.8);  units.temp.Ri = 'K'; label.temp.Ri = 'temperature';
 
% uni-variate data
% time-Weight data
data.tW_f = [ ... % time since birth (yr), female body weight (kg) in autumn
0.401	3.994
0.401	8.045
0.401	12.097
0.401	14.122
1.247	87.941
1.38	38.29
1.38	47.406
1.38	52.471
1.38	59.561
1.38	64.625
1.38	67.664
1.38	72.728
1.469	101.076
2.36	100.948
2.36	104.999
2.36	109.051
2.36	117.154
2.36	117.154
2.36	122.218
2.449	52.316
2.449	79.664
2.449	92.832
2.449	99.922
2.449	129.296
3.295	121.07
3.295	129.173
3.34	95.741
3.34	137.27
3.34	145.373
3.34	154.489
3.429	105.857
3.429	158.528
3.473	133.199
4.364	118.89
4.364	123.954
4.364	128.006
4.364	135.096
4.364	141.173
4.364	145.225
4.364	149.276
4.364	155.354
4.364	169.534
4.364	169.534
4.364	173.586
4.364	179.663
4.364	185.741
4.364	189.792
5.299	157.244
5.299	157.244
5.299	188.644
5.299	189.657
5.388	132.922
5.388	140.012
5.388	147.102
5.388	149.128
5.433	165.328
5.433	171.405
5.433	174.444
5.433	179.509
5.433	200.779
5.477	201.786
5.477	207.863
6.234	135.838
6.323	146.967
6.323	153.045
6.368	157.09
6.368	163.167
6.368	168.231
6.368	169.244
6.368	175.322
6.368	183.425
6.368	186.463
6.368	189.502
6.368	193.554
6.368	196.592
6.368	198.618
6.368	211.786
6.368	256.353
7.258	150.883
7.258	152.909
7.303	171.135
7.303	174.173
7.303	193.418
7.303	205.573
7.392	180.238
7.392	182.264
7.392	185.302
8.238	133.523
8.238	150.742
8.238	162.896
8.238	167.961
8.238	169.987
8.238	174.038
8.238	180.116
8.238	181.128
8.238	183.154
8.238	189.232
8.327	156.806
8.327	158.832
8.327	158.832
8.327	199.348
8.327	205.425
8.327	221.631
9.262	188.07
9.262	186.045
9.351	176.916
9.351	176.916
9.351	141.465
9.396	217.425
9.396	213.373
9.396	197.167
9.396	148.548
9.396	134.368
10.197	233.515
10.286	151.458
10.286	177.793
10.331	157.529
10.331	161.581
10.331	163.606
10.331	169.684
10.331	181.839
10.42	188.916
10.42	202.083
10.42	209.174
11.266	144.226
11.266	160.432
11.266	166.51
11.266	175.626
11.266	183.729
11.266	189.806
11.266	191.832
11.31	194.864
11.355	199.922
11.355	206
11.399	210.045
11.399	217.135
12.335	147.11
12.335	180.536
12.335	181.549
12.335	187.626
12.335	212.948
12.379	135.962
12.379	225.096
12.379	244.341
12.424	163.304
12.424	195.716
12.424	196.729
13.314	172.291
13.359	165.194
13.359	180.387
13.359	215.839
13.359	258.38
13.403	141.891
13.403	229
14.205	162.033
14.205	172.162
14.294	141.762
14.294	158.981
14.294	243.051
14.383	147.827
14.383	176.188
14.383	203.536
14.383	208.6
14.383	212.652
14.383	216.703
14.383	225.819
14.427	200.491
14.472	181.239
14.472	183.265
15.318	126.421
15.407	150.717
15.407	188.194
15.407	191.233
15.407	266.187
15.452	159.827
15.452	170.969
15.452	184.136
15.452	199.33
15.452	212.497
15.808	175.982
16.342	157.672
16.431	163.737
16.476	172.846
17.322	277.052
17.366	189.936
17.366	216.272
17.411	198.033
17.411	212.214
18.302	179.672
18.346	200.937
18.391	272.845
18.435	236.375
19.326	159.266
20.305	159.124
20.483	187.46
21.374	158.97
21.419	194.415
21.463	170.099
22.309	191.247
22.398	169.963
22.487	201.35
23.333	170.841
23.467	213.363
24.358	148.409
26.45	193.686
28.276	210.641
32.328	189.797];
data.tW_f(:,1) = data.tW_f(:,1) * 365; % convert yr to d
data.tW_f(:,2) = 1000 * data.tW_f(:,2); % convert kg to g
units.tW_f   = {'d', 'g'};  label.tW_f = {'time since birth', 'wet weight', 'female'};  
temp.tW_f    = C2K(36.8);  units.temp.tW_f = 'K'; label.temp.tW_f = 'temperature';
bibkey.tW_f = 'DeroWiig2002';
comment.tW_f = 'data for females';
%
data.tW_m = [ ... % time since birth (yr), male body weight (kg) in autumn
0.312	26.29
0.401	13.11
0.445	8.039
0.49	22.213
1.202	78.832
1.291	72.741
1.336	47.413
1.336	88.941
1.336	112.238
1.336	143.637
1.425	63.606
1.425	65.632
1.559	128.412
2.271	96.909
2.271	108.051
2.271	108.051
2.271	111.089
2.316	134.379
2.316	227.565
2.36	113.102
2.405	202.23
2.449	68.522
2.449	82.703
2.449	168.798
2.538	192.082
3.251	231.482
3.34	130.18
3.34	162.592
3.34	184.876
3.34	189.94
3.34	241.598
3.384	222.346
3.429	152.45
3.429	215.25
4.319	197.902
4.319	206.005
4.319	215.121
4.319	238.417
4.408	174.592
4.408	182.695
4.408	272.843
5.299	186.618
5.344	353.739
5.388	197.747
5.433	207.87
5.477	290.92
5.477	313.204
6.19	372.861
6.279	258.392
6.279	282.701
6.323	214.831
6.323	234.076
6.323	310.043
6.368	401.196
7.303	223.805
7.303	298.759
7.303	303.824
7.347	206.58
7.347	260.263
7.392	228.857
7.392	245.063
7.392	422.319
7.392	452.706
8.193	413.087
8.282	225.689
8.327	264.173
8.327	310.766
8.327	338.114
8.327	454.596
8.372	231.754
8.372	377.61
8.372	465.732
8.416	371.526
8.416	395.836
8.416	406.977
9.351	433.177
9.396	506.099
9.396	461.532
10.242	513.067
10.286	433.042
10.331	220.328
10.331	336.811
10.331	338.837
10.375	331.74
10.42	361.107
10.464	268.928
10.464	354.011
10.464	364.14
10.464	366.165
10.464	374.269
10.464	379.333
10.464	424.913
10.553	309.431
11.266	324.521
11.355	503.79
11.355	377.178
11.355	361.985
11.355	350.843
11.355	301.211
11.399	455.164
11.444	428.823
11.444	315.379
12.246	450.991
12.29	461.113
12.29	294.999
12.29	342.605
12.29	378.056
12.335	419.578
12.335	415.526
12.379	236.238
12.424	412.475
12.424	403.359
12.424	315.237
12.468	523.886
12.468	306.115
13.359	401.198
13.403	454.875
13.403	326.237
13.448	406.249
13.448	316.102
13.448	350.54
13.492	442.707
13.492	430.552
13.492	430.552
14.205	300.799
14.249	409.172
14.383	347.366
14.472	492.197
14.472	451.681
14.472	371.663
14.517	334.179
14.517	378.747
14.561	275.425
14.606	358.476
15.229	451.572
15.318	418.133
15.452	407.985
15.452	337.083
15.496	338.089
16.342	429.127
16.431	313.645
17.411	341.864
17.455	328.69
17.455	337.806
18.212	355.928
18.346	410.605
18.391	374.134
18.48	391.341
18.48	400.457
19.415	422.605
19.415	369.935
19.459	402.341
20.261	394.122
20.261	398.173
20.261	404.251
20.261	409.315
20.261	420.457
20.261	425.521
20.261	474.14
20.305	335.368
20.439	313.065
20.439	378.903
20.439	379.915
20.483	347.496
21.33	414.225
21.33	369.658
21.374	374.716
21.374	335.213
21.508	434.457
22.22	401.941
22.309	360.4
22.398	409.006
22.443	385.703
24.447	369.207
25.515	253.582
26.317	428.697];
data.tW_m(:,1) = data.tW_m(:,1) * 365; % convert yr to d
data.tW_m(:,2) = 1000 * data.tW_m(:,2); % convert kg to g
units.tW_m   = {'d', 'g'}; label.tW_m = {'time since birth', 'wet weight', 'male'};  
temp.tW_m    = C2K(36.8);  units.temp.tW_m = 'K'; label.temp.tW_m = 'temperature';
bibkey.tW_m = 'DeroWiig2002';
comment.tW_m = 'data for males';
  
% t-L data
data.tL_f = [ ... % time since birth (yr), female head-body length (cm) in autumn
0.3098	84.3143
0.3126	72.0007
0.3565	78.7148
0.3575	74.2371
0.3606	60.431
0.4042	68.6376
0.4053	63.7868
0.4067	57.4434
0.4082	50.7269
0.4468	80.5756
0.4931	76.8418
0.6654	117.5043
0.7102	120.1138
1.2013	156.6548
1.251	137.6223
1.337	158.8864
1.3401	145.0802
1.3821	160.0034
1.3838	152.5406
1.3847	148.8092
1.3901	124.9283
1.3911	120.4506
1.4335	133.8812
1.4758	147.3118
1.5226	140.966
1.5692	135.7397
1.6544	160.362
2.2883	167.7909
2.2899	160.7012
2.2917	152.4922
2.3411	134.9522
2.3816	156.5919
2.4251	165.1717
2.56	170.7615
2.8323	171.1201
3.1971	163.638
3.289	158.7823
3.3307	175.198
3.3737	185.6435
3.3743	183.0315
3.3747	181.1658
3.3763	174.0762
3.5088	190.487
3.6957	166.9696
4.2823	182.61
4.2867	163.2067
4.3253	193.4286
4.326	190.0703
4.3267	187.0852
4.3297	174.0254
4.3305	170.294
4.5547	182.5954
4.7353	187.0634
5.1891	187.7855
5.2336	191.5145
5.3223	200.8381
5.3263	183.3006
5.3267	181.4349
5.3274	178.4498
5.3672	202.7014
5.3689	195.2386
5.3695	192.6266
5.3701	190.0147
5.4142	195.9825
5.4164	186.2809
5.6879	189.9977
6.2315	195.1926
6.2749	203.7724
6.2758	200.041
6.276	198.9216
6.2776	191.832
6.2777	191.4588
6.278	189.9663
6.2785	188.1006
6.2791	185.4886
6.3228	192.949
6.3705	182.8718
6.4169	178.3917
6.458	197.0462
6.4581	196.6731
6.5955	191.4419
6.5962	188.4568
6.6399	195.9171
7.2318	188.0498
7.2331	182.4527
7.2752	196.6295
7.3632	209.3114
7.3648	202.2218
7.3665	194.3859
7.3666	194.0127
7.3676	189.9082
7.4093	205.9507
7.4143	183.9356
7.5025	195.498
7.7302	192.1277
7.7749	195.4835
8.1376	197.3298
8.3195	195.8276
8.3195	195.8276
8.3199	194.335
8.3205	191.7231
8.321	189.4842
8.3214	187.6185
8.3222	183.8872
8.3228	181.2752
8.4086	203.2855
8.4549	199.5517
9.3169	201.7446
9.363	198.7571
9.3635	196.5182
9.3636	195.7719
9.3638	195.0257
9.3641	193.9062
9.3643	192.7868
9.3646	191.2943
9.3653	188.3092
9.3657	186.4435
9.7246	205.4542
10.1808	195.7284
10.2253	199.4574
10.2716	195.3504
10.2749	180.798
10.3153	202.8108
10.359	210.2711
10.3629	193.1067
10.454	191.9825
10.4545	189.7436
10.4545	189.7436
10.6353	193.0922
10.771	195.3238
11.2702	196.0434
11.2705	194.5509
11.2706	194.1778
11.3163	192.6828
11.3595	202.7551
11.3597	201.6357
11.36	200.5163
11.3602	199.3969
11.3603	199.0237
11.3606	197.5312
11.3622	190.8147
11.3624	189.6952
11.3624	189.6952
11.3631	186.7101
12.27	191.1394
12.2707	188.1543
12.2708	187.408
12.2714	185.1692
12.3114	208.6745
12.3591	198.5973
12.3594	197.1048
12.4037	201.9532
12.4055	194.1173
12.406	191.8784
12.4506	195.6074
12.4511	193.3686
12.496	195.605
13.1739	209.0017
13.2206	203.029
13.3573	200.7829
13.3595	191.0813
13.3605	186.6037
13.3615	182.126
13.362	180.2603
13.4041	194.8103
13.5391	199.6538
13.5856	194.8006
13.6319	191.0668
14.131	192.1596
14.2645	204.0928
14.2655	199.6151
14.2656	199.242
14.2672	192.1524
14.2679	189.1672
14.269	184.3164
14.2692	183.197
14.2695	181.7045
14.3101	202.971
14.3116	196.6276
14.3118	195.5082
14.3575	194.3863
14.3575	194.3863
14.6306	191.0136
14.7662	193.6183
15.265	195.8305
15.265	195.8305
15.2654	194.3379
15.3085	204.4103
15.3103	196.5744
15.3112	192.4698
15.3116	190.6041
15.3119	189.4847
15.3126	186.4996
15.3524	210.7512
15.3539	204.4079
15.4455	200.6716
15.4918	196.9378
16.3997	196.8894
16.4008	192.0386
17.2175	193.8608
17.2598	207.2913
17.3539	192.7341
18.1238	200.902
18.3522	194.9197
18.8054	197.8806
19.3521	189.2694
20.2597	190.7135
20.4403	195.1815
21.3042	189.1653
21.3492	190.6554
22.2556	197.3235
22.3003	200.6794
22.3928	192.8386
23.2983	203.6112
23.3007	193.1634
24.3464	186.0181
26.3864	198.2228
28.3822	205.5791
32.2887	194.5499];
data.tL_f(:,1) = data.tL_f(:,1) * 365; % convert yr to d
units.tL_f   = {'d', 'cm'}; label.tL_f = {'time since birth', 'length', 'female'};  
temp.tL_f    = C2K(36.8);  units.temp.tL_f = 'K'; label.temp.tL_f = 'temperature';
bibkey.tL_f = 'DeroWiig2002';
comment.tL_f = 'data for females';
%
data.tL_m = [ ... % time since birth (yr), male head-body length (cm) in autumn
0.357	76.4759
0.3576	73.864
0.3582	71.252
0.359	67.5206
0.4051	64.5331
0.4431	96.9937
0.4452	88.0384
0.447	79.8293
0.8011	119.7358
0.8027	112.6462
1.2052	139.4904
1.2925	154.7843
1.3323	179.409
1.3356	164.8566
1.3367	160.0058
1.3842	151.048
1.385	147.3166
1.3859	143.5853
1.3879	134.6299
1.3892	129.0328
1.3899	125.6746
1.4258	167.4637
1.432	140.2246
1.7436	167.4468
1.7446	162.9691
2.0167	164.4472
2.2812	198.7614
2.2831	190.5524
2.3321	174.505
2.3795	165.9204
2.3805	161.4427
2.3829	150.9948
2.3848	142.4126
2.4174	198.7542
2.4195	189.4257
2.6942	179.3364
3.1908	191.6234
3.2811	193.4842
3.3309	174.4517
3.3664	217.7334
3.3702	201.3153
3.3713	196.0914
3.3718	194.2257
3.3735	186.7629
3.3753	178.5538
3.3787	163.6283
3.7358	190.4749
3.74	171.818
4.238	177.7616
4.3186	222.5334
4.3248	195.2943
4.3305	170.294
4.3674	207.6054
5.2752	208.3033
5.3611	229.9405
5.3628	222.4777
5.3678	200.0894
5.4093	217.6245
5.7286	210.5179
6.2261	218.7004
6.3594	231.3798
6.3621	219.8125
6.4086	214.9593
7.3128	231.329
7.3174	210.8064
7.3176	210.0601
7.3612	217.8936
7.3625	212.2965
8.2651	235.7559
8.2688	219.3378
8.2708	210.3824
8.3171	206.2755
8.357	230.9002
8.4029	228.2858
8.4033	226.7933
8.4058	215.5991
8.6279	237.2291
8.6292	231.2589
9.1749	227.1253
9.262	243.5386
9.357	224.8768
10.3077	236.3933
10.311	221.8408
10.3117	218.8557
10.3133	211.7661
10.3143	207.2884
10.3506	247.585
10.354	232.6595
10.3545	230.4206
10.3552	227.0624
10.6261	233.7643
11.2134	246.0465
11.2148	240.0763
11.3064	236.34
11.309	225.1459
11.3097	222.1607
11.3102	219.9219
11.3537	228.1285
11.3561	217.6807
11.396	241.5591
11.3977	234.0964
12.2128	243.0081
12.2586	241.5132
12.2591	239.2743
12.2626	223.6025
12.2634	220.2442
12.2637	218.7517
12.3051	236.2868
12.306	232.5554
12.3527	226.5828
12.3531	225.0902
12.3555	214.2692
12.4429	229.563
12.6242	230.6728
13.1698	226.9123
13.2132	235.8653
13.2596	231.3852
13.2599	229.8926
13.303	239.9649
13.3034	238.4724
13.3067	223.5468
13.3076	219.8154
13.3538	216.0816
13.3945	236.975
14.2602	222.7497
14.2613	217.8989
14.3487	232.8196
14.3505	224.9837
14.4389	235.4268
14.7135	225.7106
15.1666	229.4178
15.3453	242.0949
15.3458	239.856
15.3479	230.9007
15.3504	219.7065
16.4388	224.4993
16.618	235.3106
16.6196	227.8478
17.348	218.8538
17.5283	224.4412
17.6599	244.5834
17.8469	221.066
17.8918	223.3024
18.2535	229.6264
18.3439	231.1141
18.3912	222.9027
18.4332	237.8258
19.3397	244.1208
19.3434	227.7027
19.3449	221.3593
19.6574	244.477
20.2966	228.3981
20.3452	214.2164
20.3851	238.468
20.388	225.4082
20.3884	223.9156
20.3886	222.7962
20.4311	235.8536
20.4345	220.5549
20.5224	233.2368
20.7982	218.2968
21.3432	217.1483
21.3866	226.1012
21.3871	223.8624
21.4734	243.6339
22.2918	237.9933
22.2925	235.0081
22.2935	230.5305
22.3396	227.5429
22.7478	229.0137
24.4261	234.8944
25.4275	222.9007
26.3317	239.2704];
data.tL_m(:,1) = data.tL_m(:,1) * 365; % convert yr to d
units.tL_m   = {'d', 'cm'}; label.tL_m = {'time since birth', 'length', 'male'};  
temp.tL_m    = C2K(36.8);  units.temp.tL_m = 'K'; label.temp.tL_m = 'temperature';
bibkey.tL_m = 'DeroWiig2002';
comment.tL_m = 'data for males';

%% set weights for all real data
weights = setweights(data, []);
weights.tW_f(1:62) = weights.tW_f(1:62)*10; %give extra weight to the time-weight data than time-length
weights.tW_m(1:50) = weights.tW_m(1:50)*10;

%% set pseudodata and respective weights
[data, units, label, weights] = addpseudodata(data, units, label, weights);
data.psd.t_0 = 0;  units.psd.t_0 = 'd'; label.psd.t_0 = 'time at start development';
weights.psd.t_0 = 0.1;

%% pack auxData and txtData for output
auxData.temp = temp;
txtData.units = units;
txtData.label = label;
txtData.bibkey = bibkey;
%txtData.comment = comment;

%% Group plots
set1 = {'tW_f','tW_m'}; subtitle1 = {'Weight data for females, males'};
set2 = {'tL_f','tL_m'}; subtitle2 = {'Length data for females, males'};
metaData.grp.sets = {set1, set2};
metaData.grp.subtitle = {subtitle1, subtitle2};

%% Discussion points
D1 = 'Males are assumed to differ from females by {p_Am} only'; 
metaData.discussion = struct('D1', D1);

%% Facts
F1 = 'Size and weight differ between populations';
metaData.bibkey.F1 = 'DeroWiig2002'; 
F2 = 'Gestation includes delayed implantation of about 165 days';
metaData.bibkey.F2 = 'AnAge'; 
metaData.facts = struct('F1',F1,'F2',F2);

%% Links
metaData.links.id_CoL = '7F2J9'; % Cat of Life
metaData.links.id_ITIS = '180542'; % ITIS
metaData.links.id_EoL = '46559143'; % Ency of Life
metaData.links.id_Wiki = 'Ursus_maritimus'; % Wikipedia
metaData.links.id_ADW = 'Ursus_maritimus'; % ADW
metaData.links.id_Taxo = '170194'; % Taxonomicon
metaData.links.id_WoRMS = '137085'; % WoRMS
metaData.links.id_MSW3 = '14000987'; % MSW3
metaData.links.id_AnAge = 'Ursus_maritimus'; % AnAge


%% References
%
bibkey = 'Kooy2010'; type = 'Book'; bib = [ ...  % used in setting of chemical parameters and pseudodata
'author = {Kooijman, S.A.L.M.}, ' ...
'year = {2010}, ' ...
'title  = {Dynamic Energy Budget theory for metabolic organisation}, ' ...
'publisher = {Cambridge Univ. Press, Cambridge}, ' ...
'pages = {Table 4.2 (page 150), 8.1 (page 300)}, ' ...
'howpublished = {\url{../../../bib/Kooy2010.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'DeroWiig2002'; type = 'Article'; bib = [ ... 
'author = {Derocher, A. E. and Wiig, O.}, ' ... 
'year = {2002}, ' ...
'title = {Postnatal growth in body length and mass of polar bears (\emph{Ursus maritimus}) at {S}valbard}, ' ...
'journal = {Journal of Zoology}, ' ...
'howpublished = {\url{http://http://onlinelibrary.wiley.com/doi/10.1017/S0952836902000377/epdf}},'  ...
'volume = {256}, ' ...
'pages = {343--349}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'AnAge'; type = 'Misc'; bib = ...
'howpublished = {\url{http://genomics.senescence.info/species/entry.php?species=Ursus_maritimus}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];