function [prdData, info] = predict_Ursus_maritimus(par, data, auxData)
  
  % unpack par, data, auxData
  cPar = parscomp_st(par); vars_pull(par); 
  vars_pull(cPar);  vars_pull(data);  vars_pull(auxData);
  
% compound parameters for males
  % Need to first calculate male specific parameters that are calc in background already for females
  p_Am_m = z_m * p_M/ kap;             % J/d.cm^2, {p_Am} spec assimilation flux
  E_m_m = p_Am_m/ v;                   % J/cm^3, reserve capacity [E_m]
  g_m = E_G/ (kap* E_m_m);             % -, energy investment ratio
  m_Em_m = y_E_V * E_m_m/ E_G;         % mol/mol, reserve capacity 
  w_m = m_Em_m * w_E/ w_V;             % -, contribution of reserve to weight
  L_m_m = v/ k_M/ g_m;                 % cm, max struct length
% 
  U_Hb_m = E_Hb/ p_Am_m;                   % cm^2 d, scaled maturity at level i
  V_Hb_m = U_Hb_m/ (1 - kap);                % cm^2 d, scaled maturity at level i
  v_Hb_m = V_Hb_m * g_m^2 * k_M^3/ v^2;      % -, scaled maturity density at level i
  U_Hx_m = E_Hx/ p_Am_m;                   % cm^2 d, scaled maturity at level i
  V_Hx_m = U_Hx_m/ (1 - kap);                % cm^2 d, scaled maturity at level i
  v_Hx_m = V_Hx_m * g_m^2 * k_M^3/ v^2;      % -, scaled maturity density at level i
  U_Hp_m = E_Hp_m/ p_Am_m;                   % cm^2 d, scaled maturity at level i
  V_Hp_m = U_Hp_m/ (1 - kap);                % cm^2 d, scaled maturity at level i
  v_Hp_m = V_Hp_m * g_m^2 * k_M^3/ v^2;      % -, scaled maturity density at level i

  % life cycle for females (see females below)
  pars_txm = [g_m k l_T v_Hb v_Hx_m v_Hp]; 
  [t_p_m, t_x_m, t_b_m, l_p_m, l_x_m, l_b_m, info] = get_tx(pars_txm, f_tW); % calculate estimates for time and length points, eg. birth, weaning and puberty 
  filterChecks = k * v_Hp_m >= f * (f - l_T)^2; % constraint required for reaching puberty
 
  if filterChecks || ~info
    prdData = {};
    return;
  end  

  % compute temperature correction factors
  TC = tempcorr(temp.tg, T_ref, T_A);
  
  % zero-variate data

  % life cycle for females 
  pars_tx = [g k l_T v_Hb v_Hx v_Hp]; info = 1;
  [t_p, t_x, t_b, l_p, l_x, l_b] = get_tx(pars_tx, f);
 
  % birth
  L_b = L_m * l_b;                  % cm, structural length at birth at f
  Ww_b = L_b^3 * (1 + f * w);       % g, wet weight at birth at f 
  aT_g = t_0 + t_b/ k_M/ TC;        % d, gestation time at f and T

  % weaning
  L_x = L_m * l_x;                  % cm, structural length at weaning
  Ww_x = L_x^3 * (1 + f * w);       % g, wet weight at weaning
  tT_x = (t_x - t_b)/ k_M/ TC;      % d, time since birth at weaning at f and T
  
  % puberty 
  L_p = L_m * l_p;                  % cm, structural length at puberty
  tT_p = (t_p - t_b)/ k_M/ TC;      % d, time since birth at puberty at f and T
  Ww_p = L_p^3 * (1 + f * w);       % g, wet weight at puberty  
  
  % ultimate
  l_i = f - l_T;                    % -, scaled ultimate length
  L_i = L_m * l_i;                  % cm, ultimate structural length at f
  Lw_i = L_i/ del_M;                % cm, ultimate physical length at f
  Ww_i = L_i^3 * (1 + f * w);       % g, ultimate wet weight 
  
  % reproduction
  pars_R = [kap; kap_R; g; k_J; k_M; L_T; v; U_Hb; U_Hp]; % compose parameter vector at T
  RT_i = TC * reprod_rate_foetus(L_i, f, pars_R);         % #/d, ultimate reproduction rate at T

  % life span
  pars_tm = [g; l_T; h_a/ k_M^2; s_G];  % compose parameter vector at T_ref
  t_m = get_tm_s(pars_tm, f, l_b);      % -, scaled mean life span at T_ref
  aT_m = t_m/ k_M/ TC;                  % d, mean life span at T

  
  % Males
  %L_b_m = L_m_m * l_b_m;                  % Length at birth
  tT_p_m = (t_p_m - t_b_m)/ k_M/ TC;      % d, time since birth at puberty at f and T
  L_p_m = L_m_m * l_p_m;                  % cm, structural length at puberty
  Ww_p_m = L_p_m^3 * (1 + f * w_m);       % g, wet weight at puberty  
  L_i_m = (f - l_T) * L_m_m;              % Ultimate length
  Lw_i_m = L_i_m/ del_M;                  % ultimate physical length
  Ww_i_m = L_i_m^3 * (1 + f * w_m);       % g, ultimate wet weight 
  
  % pack to output
  prdData.tg = aT_g;
  prdData.tx = tT_x;
  prdData.tp = tT_p;
  prdData.tp_m = tT_p_m;
  prdData.am = aT_m;
  prdData.Li = Lw_i;
  prdData.Li_m = Lw_i_m;
  prdData.Wwb = Ww_b;
  prdData.Wwx = Ww_x;
  prdData.Wwp = Ww_p;
  prdData.Wwp_m = Ww_p_m;
  prdData.Wwi = Ww_i;
  prdData.Wwi_m = Ww_i_m;
  prdData.Ri = RT_i;
  
  % uni-variate data
  
  % time-weight females
  f = f_tW; pars_lb = [g; k; v_Hb];                    % compose parameters
  ir_B = 3/ k_M + 3 * f * L_m/ v; rT_B = TC/ ir_B;     % d, 1/von Bert growth rate
  L_i = f * L_m - L_T; L_b = get_lb(pars_lb, f) * L_m; % cm, length at birth, ultimate
  L = L_i - (L_i - L_b) * exp( - rT_B * tW_f(:,1));    % cm, structural length at time
  EWw_f = L.^3 * (1 + f * w);                          % g, wet weight
  
  % time-weight males
  ir_B = 3/ k_M + 3 * f * L_m_m/ v; rT_B = TC/ ir_B;    % d, 1/von Bert growth rate
  L = L_i_m - (L_i_m - L_b) * exp( - rT_B * tW_m(:,1)); % cm, structural length at time
  EWw_m = L.^3 * (1 + f * w_m);                        % g, wet weight

  % time-length females
  f = f_tW; pars_lb = [g; k; v_Hb];                    % compose parameters
  ir_B = 3/ k_M + 3 * f * L_m/ v; rT_B = TC/ ir_B;     % d, 1/von Bert growth rate
  L_i = f * L_m - L_T; L_b = get_lb(pars_lb, f) * L_m; % cm, length at birth, ultimate
  L = L_i - (L_i - L_b) * exp( - rT_B * tL_f(:,1));    % cm, structural length at time
  ELw_f = L/ del_M;                                    % cm, physical length at time
  
  % time-length males
  ir_B = 3/ k_M + 3 * f * L_m_m/ v; rT_B = TC/ ir_B;    % d, 1/von Bert growth rate
  L = L_i_m - (L_i_m - L_b) * exp( - rT_B * tL_m(:,1)); % cm, structural length at time
  ELw_m = L/ del_M;                                     % cm, physical length at time
  
  % pack to output
  prdData.tW_f = EWw_f;
  prdData.tW_m = EWw_m;
  prdData.tL_f = ELw_f; 
  prdData.tL_m = ELw_m; 
  